# django-tool
django工具
### 使用方法： ###
安装：

`pip3 install django-tool`

升级：

`pip3 install --upgrade django-tool`
使用：
`djtool`

pipy使用方法：

https://packaging.python.org/tutorials/distributing-packages/#setup-py

生成包

`python setup.py sdist`

上传包
`twine upload dist/*`